<?php
/**
 * Smallbiz Startup functions and definitions
 *
 * @package Smallbiz Startup
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

if ( ! function_exists( 'smallbiz_startup_setup' ) ) : 
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function smallbiz_startup_setup() {
	global $content_width;   
	if ( ! isset( $content_width ) )
		$content_width = 680; 

	load_theme_textdomain( 'smallbiz-startup', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'responsive-embeds' );
	add_theme_support( 'wp-block-styles');
	add_theme_support( 'align-wide' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );	
	add_theme_support( 'custom-header', array( 
		'default-text-color' => false,
		'header-text' => false,
	) );
	add_theme_support( 'custom-logo', array(
		'height'      => 100,
		'width'       => 100,
		'flex-height' => true,
	) );	
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'smallbiz-startup' ),
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );
	/*
	 * Enable support for Post Formats.
	 */
	add_theme_support( 'post-formats', array('image','video','gallery','audio',) );

	add_editor_style( 'editor-style.css' );
} 
endif; // smallbiz_startup_setup
add_action( 'after_setup_theme', 'smallbiz_startup_setup' );

function smallbiz_startup_the_breadcrumb() {
    echo '<div class="breadcrumb my-3">';

    if (!is_home()) {
        echo '<a class="home-main align-self-center" href="' . esc_url(home_url()) . '">';
        bloginfo('name');
        echo "</a>";

        if (is_category() || is_single()) {
            the_category(' , ');
            if (is_single()) {
                echo '<span class="current-breadcrumb mx-3">' . esc_html(get_the_title()) . '</span>';
            }
        } elseif (is_page()) {
            echo '<span class="current-breadcrumb mx-3">' . esc_html(get_the_title()) . '</span>';
        }
    }

    echo '</div>';
}

function smallbiz_startup_widgets_init() {
	register_sidebar( array( 
		'name'          => __( 'Blog Sidebar', 'smallbiz-startup' ),
		'description'   => __( 'Appears on blog page sidebar', 'smallbiz-startup' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'smallbiz-startup' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Add widgets here to appear in your sidebar on pages.', 'smallbiz-startup' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'smallbiz-startup' ),
		'id'            => 'sidebar-3',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'smallbiz-startup' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Shop Page Sidebar', 'smallbiz-startup' ),
		'description'   => __( 'Appears on shop page', 'smallbiz-startup' ),
		'id'            => 'woocommerce_sidebar',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Widget 1', 'smallbiz-startup' ),
		'description'   => __( 'Appears on footer', 'smallbiz-startup' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="ftr-4-box widget-column-1 %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 2', 'smallbiz-startup' ),
		'description'   => __( 'Appears on footer', 'smallbiz-startup' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="ftr-4-box widget-column-2 %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 3', 'smallbiz-startup' ),
		'description'   => __( 'Appears on footer', 'smallbiz-startup' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="ftr-4-box widget-column-3 %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 4', 'smallbiz-startup' ),
		'description'   => __( 'Appears on footer', 'smallbiz-startup' ),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="ftr-4-box widget-column-4 %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
}
add_action( 'widgets_init', 'smallbiz_startup_widgets_init' );

function smallbiz_startup_add_google_fonts() {
	wp_enqueue_style( 'smallbiz-startup-google-fonts', 'https://fonts.googleapis.com/css?family=Poppins:ital,wght@0,100;0,200;0,300;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap', false ); 
}
add_action( 'wp_enqueue_scripts', 'smallbiz_startup_add_google_fonts' );

function smallbiz_startup_scripts() {
	wp_enqueue_style( 'bootstrap-css', esc_url(get_template_directory_uri())."/css/bootstrap.css" );
	wp_enqueue_style( 'smallbiz-startup-style', get_stylesheet_uri() );
	wp_style_add_data('smallbiz-startup-style', 'rtl', 'replace');
	wp_enqueue_style( 'smallbiz-startup-responsive', esc_url(get_template_directory_uri())."/css/responsive.css" );
	wp_enqueue_style( 'smallbiz-startup-default', esc_url(get_template_directory_uri())."/css/default.css" );
	wp_enqueue_script( 'bootstrap-js', esc_url(get_template_directory_uri()). '/js/bootstrap.js', array('jquery') );
	wp_enqueue_script( 'smallbiz-startup-theme', esc_url(get_template_directory_uri()) . '/js/theme.js' );
	wp_enqueue_style( 'font-awesome-css', esc_url(get_template_directory_uri())."/css/fontawesome-all.css" );	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	require_once get_theme_file_path( 'inc/wptt-webfont-loader.php' );

	require get_parent_theme_file_path( '/inc/color-scheme/custom-color-control.php' );
	wp_add_inline_style( 'smallbiz-startup-style',$smallbiz_startup_color_scheme_css );

	// font-family
	$headings_font = esc_html(get_theme_mod('smallbiz_startup_headings_fonts'));
	$body_font = esc_html(get_theme_mod('smallbiz_startup_body_fonts'));

	if ($headings_font) {
	    wp_enqueue_style('smallbiz-startup-headings-fonts', 'https://fonts.googleapis.com/css?family=' . $headings_font);
	} else {
	    wp_enqueue_style('emilys', 'https://fonts.googleapis.com/css?family=Merienda+One');
	}

	if ($body_font) {
	    wp_enqueue_style('poppins', 'https://fonts.googleapis.com/css?family=' . $body_font);
	} else {
	    wp_enqueue_style('smallbiz-startup-source-body', 'https://fonts.googleapis.com/css?family=Poppins:0,100,200,300,400,500,600,700,800,900,1,100,1,200,1,300,1,400,1,500,1,600,1,700,1,800,1,900');
	}

}

add_action( 'wp_enqueue_scripts', 'smallbiz_startup_scripts' );

// Footer Link
define('SMALLBIZ_STARTUP_FOOTER_LINK',__('https://www.theclassictemplates.com/wp-themes/free-wordpress-startup-theme/','smallbiz-startup'));

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Theme Info Page.
 */
require get_template_directory() . '/inc/addon.php';

/**
 * Google Fonts
 */
require get_template_directory() . '/inc/gfonts.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/upgrade-to-pro.php';

/* Starter Content */
	add_theme_support( 'starter-content', array(
		'widgets' => array(
			'footer-1' => array(
				'categories',
			),
			'footer-2' => array(
				'archives',
			),
			'footer-3' => array(
				'meta',
			),
			'footer-4' => array(
				'search',
			),
		),
    ));

// logo
if ( ! function_exists( 'smallbiz_startup_the_custom_logo' ) ) :
/**
 * Displays the optional custom logo.
 *
 * Does nothing if the custom logo is not available.
 *
 */
function smallbiz_startup_the_custom_logo() {
	if ( function_exists( 'the_custom_logo' ) ) {
		the_custom_logo();
	}
}
endif;


$woocommerce_sidebar = get_theme_mod( 'smallbiz_startup_woocommerce_sidebar_product' );
	if ( 'false' == $woocommerce_sidebar ) {
$woo_product_column = 'col-lg-12 col-md-12';
	} else { 
$woo_product_column = 'col-lg-9 col-md-9';
}

$woocommerce_shop_sidebar = get_theme_mod( 'smallbiz_startup_woocommerce_sidebar_shop' );
	if ( 'false' == $woocommerce_shop_sidebar ) {
$woo_shop_column = 'col-lg-12 col-md-12';
	} else { 
$woo_shop_column = 'col-lg-9 col-md-9';
}

if ( ! defined( 'SMALLBIZ_STARTUP_PRO_NAME' ) ) {
	define( 'SMALLBIZ_STARTUP_PRO_NAME', __( 'About Smallbiz Startup', 'smallbiz-startup' ));
}

if ( ! defined( 'SMALLBIZ_STARTUP_THEME_PAGE' ) ) {
define('SMALLBIZ_STARTUP_THEME_PAGE',__('https://www.theclassictemplates.com/themes/','smallbiz-startup'));
}
if ( ! defined( 'SMALLBIZ_STARTUP_SUPPORT' ) ) {
define('SMALLBIZ_STARTUP_SUPPORT',__('https://wordpress.org/support/theme/smallbiz-startup','smallbiz-startup'));
}
if ( ! defined( 'SMALLBIZ_STARTUP_REVIEW' ) ) {
define('SMALLBIZ_STARTUP_REVIEW',__('https://wordpress.org/support/theme/smallbiz-startup/reviews/#new-post','smallbiz-startup'));
}
if ( ! defined( 'SMALLBIZ_STARTUP_PRO_DEMO' ) ) {
define('SMALLBIZ_STARTUP_PRO_DEMO',__('https://www.theclassictemplates.com/demo/smallbiz-startup/','smallbiz-startup'));
}
if ( ! defined( 'SMALLBIZ_STARTUP_PREMIUM_PAGE' ) ) {
define('SMALLBIZ_STARTUP_PREMIUM_PAGE',__('https://www.theclassictemplates.com/wp-themes/wordpress-startup-theme/','smallbiz-startup'));
}
if ( ! defined( 'SMALLBIZ_STARTUP_THEME_DOCUMENTATION' ) ) {
define('SMALLBIZ_STARTUP_THEME_DOCUMENTATION',__('http://theclassictemplates.com/documentation/smallbiz-startup-free/','smallbiz-startup'));
}

//sanitize number field
function smallbiz_startup_sanitize_number_absint( $number, $setting ) {
  // Ensure $number is an absolute integer (whole number, zero or greater).
  $number = absint( $number );

  // If the input is an absolute integer, return it; otherwise, return the default
  return ( $number ? $number : $setting->default );
}

/*radio button sanitization*/
function smallbiz_startup_sanitize_choices( $input, $setting ) {
    global $wp_customize;
    $control = $wp_customize->get_control( $setting->id );
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

if ( ! function_exists( 'smallbiz_startup_sanitize_integer' ) ) {
	function smallbiz_startup_sanitize_integer( $input ) {
		return (int) $input;
	}
}
