<?php
/**
 * Smallbiz Startup Theme Customizer
 *
 * @package Smallbiz Startup
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function smallbiz_startup_customize_register( $wp_customize ) {

	function smallbiz_startup_sanitize_dropdown_pages( $page_id, $setting ) {
  		$page_id = absint( $page_id );
  		return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
	}

	function smallbiz_startup_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	}

	wp_enqueue_style('smallbiz-startup-customize-controls', trailingslashit(esc_url(get_template_directory_uri())).'/css/customize-controls.css');

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	//Logo
    $wp_customize->add_setting('smallbiz_startup_logo_width',array(
		'default'=> '',
		'transport' => 'refresh',
		'sanitize_callback' => 'smallbiz_startup_sanitize_integer'
	));
	$wp_customize->add_control(new Smallbiz_Startup_Slider_Custom_Control( $wp_customize, 'smallbiz_startup_logo_width',array(
		'label'	=> esc_html__('Logo Width','smallbiz-startup'),
		'section'=> 'title_tagline',
		'settings'=>'smallbiz_startup_logo_width',
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 100,
        ),
	)));

	$wp_customize->add_setting('smallbiz_startup_title_enable',array(
		'default' => true,
		'sanitize_callback' => 'smallbiz_startup_sanitize_checkbox',
	));
	$wp_customize->add_control( 'smallbiz_startup_title_enable', array(
	   'settings' => 'smallbiz_startup_title_enable',
	   'section'   => 'title_tagline',
	   'label'     => __('Enable Site Title','smallbiz-startup'),
	   'type'      => 'checkbox'
	)); 

	// site title color
	$wp_customize->add_setting('smallbiz_startup_sitetitle_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_sitetitle_color', array(
	   'settings' => 'smallbiz_startup_sitetitle_color',
	   'section'   => 'title_tagline',
	   'label' => __('Site Title Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	$wp_customize->add_setting('smallbiz_startup_tagline_enable',array(
		'default' => true,
		'sanitize_callback' => 'smallbiz_startup_sanitize_checkbox',
	));
	$wp_customize->add_control( 'smallbiz_startup_tagline_enable', array(
	   'settings' => 'smallbiz_startup_tagline_enable',
	   'section'   => 'title_tagline',
	   'label'     => __('Enable Site Tagline','smallbiz-startup'),
	   'type'      => 'checkbox'
	));

	// site tagline color
	$wp_customize->add_setting('smallbiz_startup_sitetagline_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_sitetagline_color', array(
	   'settings' => 'smallbiz_startup_sitetagline_color',
	   'section'   => 'title_tagline',
	   'label' => __('Site Tagline Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// woocommerce section
	$wp_customize->add_section('smallbiz_startup_woocommerce_page_settings', array(
		'title'    => __('WooCommerce Page Settings', 'smallbiz-startup'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

    // shop page sidebar alignment
    $wp_customize->add_setting('smallbiz_startup_shop_page_sidebar_position', array(
		'default'           => 'Right Sidebar',
		'sanitize_callback' => 'smallbiz_startup_sanitize_choices',
	));
	$wp_customize->add_control('smallbiz_startup_shop_page_sidebar_position',array(
		'type'           => 'radio',
		'label'          => __('Shop Page Sidebar', 'smallbiz-startup'),
		'section'        => 'smallbiz_startup_woocommerce_page_settings',
		'choices'        => array(
			'Left Sidebar'  => __('Left Sidebar', 'smallbiz-startup'),
			'Right Sidebar' => __('Right Sidebar', 'smallbiz-startup'),
		),
	));
	
	//Theme Options
	$wp_customize->add_panel( 'smallbiz_startup_panel_area', array(
		'priority' => 10,
		'capability' => 'edit_theme_options',
		'title' => __( 'Theme Options Panel', 'smallbiz-startup' ),
	) );
	
	//Site Layout Section
	$wp_customize->add_section('smallbiz_startup_site_layoutsec',array(
		'title'	=> __('Manage Site Layout Section ','smallbiz-startup'),
		'description' => __('<p class="sec-title">Manage Site Layout Section</p>','smallbiz-startup'),
		'priority'	=> 1,
		'panel' => 'smallbiz_startup_panel_area',
	));		
	
	$wp_customize->add_setting('smallbiz_startup_box_layout',array(
		'sanitize_callback' => 'smallbiz_startup_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'smallbiz_startup_box_layout', array(
	   'section'   => 'smallbiz_startup_site_layoutsec',
	   'label'	=> __('Check to Box Layout','smallbiz-startup'),
	   'type'      => 'checkbox'
 	));

 	// Header Section
	$wp_customize->add_section('smallbiz_startup_header_section', array(
        'title' => __('Manage Header Section', 'smallbiz-startup'),
		'description' => __('<p class="sec-title">Manage Header Section</p>','smallbiz-startup'),
        'priority' => null,
		'panel' => 'smallbiz_startup_panel_area',
 	));

 	$wp_customize->add_setting('smallbiz_startup_stickyheader',array(
		'default' => false,
		'sanitize_callback' => 'smallbiz_startup_sanitize_checkbox',
	));

	$wp_customize->add_control( 'smallbiz_startup_stickyheader', array(
	   'section'   => 'smallbiz_startup_header_section',
	   'label'	=> __('Check To Show Sticky Header','smallbiz-startup'),
	   'type'      => 'checkbox'
 	));

	// logobg color
	$wp_customize->add_setting('smallbiz_startup_logobg_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_logobg_color', array(
	   'settings' => 'smallbiz_startup_logobg_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' Logo BG Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));


	// logoborder1 color
	$wp_customize->add_setting('smallbiz_startup_logoborder1_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_logoborder1_color', array(
	   'settings' => 'smallbiz_startup_logoborder1_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' Logo Border Color 1', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// logoborder2 color
	$wp_customize->add_setting('smallbiz_startup_logoborder2_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_logoborder2_color', array(
	   'settings' => 'smallbiz_startup_logoborder2_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' Logo Border Color 2', 'smallbiz-startup'),
	   'type'      => 'color'
	));


	// bg1 color
	$wp_customize->add_setting('smallbiz_startup_bg1_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_bg1_color', array(
	   'settings' => 'smallbiz_startup_bg1_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' BG Color 1', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// bg2 color
	$wp_customize->add_setting('smallbiz_startup_bg2_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_bg2_color', array(
	   'settings' => 'smallbiz_startup_bg2_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' BG Color 2', 'smallbiz-startup'),
	   'type'      => 'color'
	));



	$wp_customize->add_setting('smallbiz_startup_email_address',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_email',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_email_address', array(
	   'settings' => 'smallbiz_startup_email_address',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __('Add Email Address', 'smallbiz-startup'),
	   'type'      => 'text'
	));

	// email color
	$wp_customize->add_setting('smallbiz_startup_email_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_email_color', array(
	   'settings' => 'smallbiz_startup_email_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' Email Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));


	// socialicons color
	$wp_customize->add_setting('smallbiz_startup_socialicons_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_socialicons_color', array(
	   'settings' => 'smallbiz_startup_socialicons_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' Social Icons Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// socialiconshover color
	$wp_customize->add_setting('smallbiz_startup_socialiconshover_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_socialiconshover_color', array(
	   'settings' => 'smallbiz_startup_socialiconshover_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' Social Icons Hover Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));


	$wp_customize->add_setting('smallbiz_startup_contact_us_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_contact_us_text', array(
	   'settings' => 'smallbiz_startup_contact_us_text',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __('Add Button Text', 'smallbiz-startup'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('smallbiz_startup_contact_us_url',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_contact_us_url', array(
	   'settings' => 'smallbiz_startup_contact_us_url',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __('Add Button URL', 'smallbiz-startup'),
	   'type'      => 'url'
	));


	// buttontext color
	$wp_customize->add_setting('smallbiz_startup_buttontext_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_buttontext_color', array(
	   'settings' => 'smallbiz_startup_buttontext_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' Button Text Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// buttonbg1 color
	$wp_customize->add_setting('smallbiz_startup_buttonbg1_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_buttonbg1_color', array(
	   'settings' => 'smallbiz_startup_buttonbg1_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' Button BG Color 1', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// buttonbg2 color
	$wp_customize->add_setting('smallbiz_startup_buttonbg2_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_buttonbg2_color', array(
	   'settings' => 'smallbiz_startup_buttonbg2_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' Button BG Color 2', 'smallbiz-startup'),
	   'type'      => 'color'
	));


	// buttonhover color
	$wp_customize->add_setting('smallbiz_startup_buttonhover_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_buttonhover_color', array(
	   'settings' => 'smallbiz_startup_buttonhover_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' Button Hover Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));


	// meuns color
	$wp_customize->add_setting('smallbiz_startup_meuns_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_meuns_color', array(
	   'settings' => 'smallbiz_startup_meuns_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' Menus Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));


	// meunshover color
	$wp_customize->add_setting('smallbiz_startup_meunshover_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_meunshover_color', array(
	   'settings' => 'smallbiz_startup_meunshover_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' Menus Hover Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));


	// submeuns color
	$wp_customize->add_setting('smallbiz_startup_submeuns_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_submeuns_color', array(
	   'settings' => 'smallbiz_startup_submeuns_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' SubMenus Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// submeunshover color
	$wp_customize->add_setting('smallbiz_startup_submeunshover_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_submeunshover_color', array(
	   'settings' => 'smallbiz_startup_submeunshover_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' SubMenus Hover Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// submeunsbg color
	$wp_customize->add_setting('smallbiz_startup_submeunsbg_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_submeunsbg_color', array(
	   'settings' => 'smallbiz_startup_submeunsbg_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' SubMenus BG Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));


	// submeunsborder color
	$wp_customize->add_setting('smallbiz_startup_submeunsborder_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'smallbiz_startup_submeunsborder_color', array(
	   'settings' => 'smallbiz_startup_submeunsborder_color',
	   'section'   => 'smallbiz_startup_header_section',
	   'label' => __(' SubMenus Border Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));



	// Social media Section
	$wp_customize->add_section('smallbiz_startup_social_media_section', array(
        'title' => __('Manage Social Media Section', 'smallbiz-startup'),
		'description' => __('<p class="sec-title">Manage Social Media Section</p>','smallbiz-startup'),
        'priority' => null,
		'panel' => 'smallbiz_startup_panel_area',
 	));

	$wp_customize->add_setting('smallbiz_startup_fb_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_fb_link', array(
	   'settings' => 'smallbiz_startup_fb_link',
	   'section'   => 'smallbiz_startup_social_media_section',
	   'label' => __('Facebook Link', 'smallbiz-startup'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('smallbiz_startup_twitt_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_twitt_link', array(
	   'settings' => 'smallbiz_startup_twitt_link',
	   'section'   => 'smallbiz_startup_social_media_section',
	   'label' => __('Twitter Link', 'smallbiz-startup'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('smallbiz_startup_linked_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_linked_link', array(
	   'settings' => 'smallbiz_startup_linked_link',
	   'section'   => 'smallbiz_startup_social_media_section',
	   'label' => __('Linkdin Link', 'smallbiz-startup'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('smallbiz_startup_insta_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_insta_link', array(
	   'settings' => 'smallbiz_startup_insta_link',
	   'section'   => 'smallbiz_startup_social_media_section',
	   'label' => __('Instagram Link', 'smallbiz-startup'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('smallbiz_startup_youtube_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_youtube_link', array(
	   'settings' => 'smallbiz_startup_youtube_link',
	   'section'   => 'smallbiz_startup_social_media_section',
	   'label' => __('Youtube Link', 'smallbiz-startup'),
	   'type'      => 'url'
	));

	// Home Category Dropdown Section
	$wp_customize->add_section('smallbiz_startup_one_cols_section',array(
		'title'	=> __('Manage Banner Section','smallbiz-startup'),
		'description'	=> __('<p class="sec-title">Manage Banner Section</p> Select Page from the Dropdown for banner, Also use the given image dimension (500 x 500).','smallbiz-startup'),
		'priority'	=> null,
		'panel' => 'smallbiz_startup_panel_area'
	));

	//Hide Section
	$wp_customize->add_setting('smallbiz_startup_disabled_pgboxes_1',array(
		'default' => false,
		'sanitize_callback' => 'smallbiz_startup_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 
	$wp_customize->add_control( 'smallbiz_startup_disabled_pgboxes_1', array(
	   'settings' => 'smallbiz_startup_disabled_pgboxes_1',
	   'section'   => 'smallbiz_startup_one_cols_section',
	   'label'     => __('Check To Enable This Section','smallbiz-startup'),
	   'type'      => 'checkbox'
	));

	$wp_customize->add_setting('smallbiz_startup_pgboxes_title',array(
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control( 'smallbiz_startup_pgboxes_title', array(
	   'section'   => 'smallbiz_startup_one_cols_section',
	   'label'	=> __('Section Title','smallbiz-startup'),
	   'type'      => 'text',
	   'priority' => null,
    ));
	
	$wp_customize->add_setting('smallbiz_startup_pageboxes',array(
		'default'	=> '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'smallbiz_startup_sanitize_dropdown_pages'
	));
	$wp_customize->add_control(	'smallbiz_startup_pageboxes',array(
		'type' => 'dropdown-pages',
		'section' => 'smallbiz_startup_one_cols_section',
	  'label' => __( 'Select Page to display Banner','smallbiz-startup'),
	));

	$wp_customize->add_setting( 'smallbiz_startup_banner_excerpt_number', array(
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'smallbiz_startup_sanitize_number_absint',
	  'default' => 40,
	) );
	$wp_customize->add_control( 'smallbiz_startup_banner_excerpt_number', array(
	  'settings' => 'smallbiz_startup_banner_excerpt_number',
	  'type' => 'number',
	  'section' => 'smallbiz_startup_one_cols_section',
	  'label' => __( 'Number Of Words To Show','smallbiz-startup'),
	) );
	
	$wp_customize->add_setting('smallbiz_startup_button_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_button_text', array(
	   'settings' => 'smallbiz_startup_button_text',
	   'section'   => 'smallbiz_startup_one_cols_section',
	   'label' => __('Add Button Text', 'smallbiz-startup'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('smallbiz_startup_button_link_slider',array(
        'default'=> '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('smallbiz_startup_button_link_slider',array(
        'label' => esc_html__('Add Button Link','smallbiz-startup'),
        'section'=> 'smallbiz_startup_one_cols_section',
        'type'=> 'url'
    ));
 
	// banner title color
	$wp_customize->add_setting('smallbiz_startup_bannertitle_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_bannertitle_color', array(
	   'settings' => 'smallbiz_startup_bannertitle_color',
	   'section'   => 'smallbiz_startup_one_cols_section',
	   'label' => __(' Section Title Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// banner subtitle color
	$wp_customize->add_setting('smallbiz_startup_bannersubtitle_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_bannersubtitle_color', array(
	   'settings' => 'smallbiz_startup_bannersubtitle_color',
	   'section'   => 'smallbiz_startup_one_cols_section',
	   'label' => __(' SubTitle Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// banner description color
	$wp_customize->add_setting('smallbiz_startup_bannerdescription_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_bannerdescription_color', array(
	   'settings' => 'smallbiz_startup_bannerdescription_color',
	   'section'   => 'smallbiz_startup_one_cols_section',
	   'label' => __(' Description Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// banner btnbg1 color
	$wp_customize->add_setting('smallbiz_startup_bannerbtnbg1_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_bannerbtnbg1_color', array(
	   'settings' => 'smallbiz_startup_bannerbtnbg1_color',
	   'section'   => 'smallbiz_startup_one_cols_section',
	   'label' => __(' Button BG Color 1', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// banner btnbg2 color
	$wp_customize->add_setting('smallbiz_startup_bannerbtnbg2_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_bannerbtnbg2_color', array(
	   'settings' => 'smallbiz_startup_bannerbtnbg2_color',
	   'section'   => 'smallbiz_startup_one_cols_section',
	   'label' => __(' Button BG Color 2', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// banner btntext color
	$wp_customize->add_setting('smallbiz_startup_bannerbtntext_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_bannerbtntext_color', array(
	   'settings' => 'smallbiz_startup_bannerbtntext_color',
	   'section'   => 'smallbiz_startup_one_cols_section',
	   'label' => __(' Button Text Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// banner btnhover color
	$wp_customize->add_setting('smallbiz_startup_bannerbtnhover_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_bannerbtnhover_color', array(
	   'settings' => 'smallbiz_startup_bannerbtnhover_color',
	   'section'   => 'smallbiz_startup_one_cols_section',
	   'label' => __(' Button BG Hover Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// banner rightboxbg1 color
	$wp_customize->add_setting('smallbiz_startup_bannerrightboxbg1_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_bannerrightboxbg1_color', array(
	   'settings' => 'smallbiz_startup_bannerrightboxbg1_color',
	   'section'   => 'smallbiz_startup_one_cols_section',
	   'label' => __(' Right Box BG Color 1', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// banner rightboxbg2 color
	$wp_customize->add_setting('smallbiz_startup_bannerrightboxbg2_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_bannerrightboxbg2_color', array(
	   'settings' => 'smallbiz_startup_bannerrightboxbg2_color',
	   'section'   => 'smallbiz_startup_one_cols_section',
	   'label' => __(' Right Box BG Color 2', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// banner imgborder color
	$wp_customize->add_setting('smallbiz_startup_bannerimgborder_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_bannerimgborder_color', array(
	   'settings' => 'smallbiz_startup_bannerimgborder_color',
	   'section'   => 'smallbiz_startup_one_cols_section',
	   'label' => __('Image Color', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// banner box1 color
	$wp_customize->add_setting('smallbiz_startup_bannerbox1_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_bannerbox1_color', array(
	   'settings' => 'smallbiz_startup_bannerbox1_color',
	   'section'   => 'smallbiz_startup_one_cols_section',
	   'label' => __('Box Color 1', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// banner box2 color
	$wp_customize->add_setting('smallbiz_startup_bannerbox2_color',array(
		'default' => '',
		'sanitize_callback' => 'esc_html',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_bannerbox2_color', array(
	   'settings' => 'smallbiz_startup_bannerbox2_color',
	   'section'   => 'smallbiz_startup_one_cols_section',
	   'label' => __('Box Color 2', 'smallbiz-startup'),
	   'type'      => 'color'
	));

	// Home Three Boxes Section 
	$wp_customize->add_section('smallbiz_startup_below_banner_section', array(
		'title'	=> __('Manage Services Section','smallbiz-startup'),
		'description'	=> __('<p class="sec-title">Manage Services Section</p> Select Pages from the dropdown for Services, Also use the given image dimension (500 x 500).','smallbiz-startup'),
		'priority'	=> null,
		'panel' => 'smallbiz_startup_panel_area',
	));

	$wp_customize->add_setting('smallbiz_startup_hidepageboxes',array(
		'default' => false,
		'sanitize_callback' => 'smallbiz_startup_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_hidepageboxes', array(
	   'settings' => 'smallbiz_startup_hidepageboxes',
	   'section'   => 'smallbiz_startup_below_banner_section',
	   'label'     => __('Check To Enable This Section','smallbiz-startup'),
	   'type'      => 'checkbox'
	));

	$wp_customize->add_setting('smallbiz_startup_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'smallbiz_startup_text', array(
	   'settings' => 'smallbiz_startup_text',
	   'section'   => 'smallbiz_startup_below_banner_section',
	   'label'     => __('Add Text','smallbiz-startup'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('smallbiz_startup_title',array(
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control( 'smallbiz_startup_title', array(
	   'section'   => 'smallbiz_startup_below_banner_section',
	   'label'	=> __('Section Title','smallbiz-startup'),
	   'type'      => 'text',
	   'priority' => null,
    ));
	
	$wp_customize->add_setting('smallbiz_startup_pageboxes1',array(
		'default'	=> '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'smallbiz_startup_sanitize_dropdown_pages'
	));
	$wp_customize->add_control(	'smallbiz_startup_pageboxes1',array(
		'type' => 'dropdown-pages',
	   'label'     => __('Select Page to display Service','smallbiz-startup'),
		'section' => 'smallbiz_startup_below_banner_section',
	));	

	$wp_customize->add_setting('smallbiz_startup_pageboxes2',array(
		'default'	=> '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'smallbiz_startup_sanitize_dropdown_pages'
	)); 
	$wp_customize->add_control(	'smallbiz_startup_pageboxes2',array(
		'type' => 'dropdown-pages',
	   'label'     => __('Select Page to display Service','smallbiz-startup'),
		'section' => 'smallbiz_startup_below_banner_section',
	));
	
	$wp_customize->add_setting('smallbiz_startup_pageboxes3',array(
		'default'	=> '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'smallbiz_startup_sanitize_dropdown_pages'
	));
	$wp_customize->add_control(	'smallbiz_startup_pageboxes3',array(
		'type' => 'dropdown-pages',
	   'label'     => __('Select Page to display Service','smallbiz-startup'),
		'section' => 'smallbiz_startup_below_banner_section',
	));
	
	//Blog post
	$wp_customize->add_section('smallbiz_startup_blog_post_settings',array(
        'title' => __('Manage Post Section', 'smallbiz-startup'),
        'priority' => null,
        'panel' => 'smallbiz_startup_panel_area'
    ) );

   // Add Settings and Controls for Post Layout
	$wp_customize->add_setting('smallbiz_startup_sidebar_post_layout',array(
     'default' => 'right',
     'sanitize_callback' => 'smallbiz_startup_sanitize_choices'
	));
	$wp_customize->add_control('smallbiz_startup_sidebar_post_layout',array(
     'type' => 'radio',
     'label'     => __('Theme Post Sidebar Position', 'smallbiz-startup'),
     'description'   => __('This option work for blog page, archive page and search page.', 'smallbiz-startup'),
     'section' => 'smallbiz_startup_blog_post_settings',
     'choices' => array(
         'full' => __('Full','smallbiz-startup'),
         'left' => __('Left','smallbiz-startup'),
         'right' => __('Right','smallbiz-startup'),
         'three-column' => __('Three Columns','smallbiz-startup'),
         'four-column' => __('Four Columns','smallbiz-startup'),
         'grid' => __('Grid Layout','smallbiz-startup')
     ),
	) );

	$wp_customize->add_setting('smallbiz_startup_blog_post_description_option',array(
    	'default'   => 'Full Content', 
        'sanitize_callback' => 'smallbiz_startup_sanitize_choices'
	));
	$wp_customize->add_control('smallbiz_startup_blog_post_description_option',array(
        'type' => 'radio',
        'label' => __('Post Description Length','smallbiz-startup'),
        'section' => 'smallbiz_startup_blog_post_settings',
        'choices' => array(
            'No Content' => __('No Content','smallbiz-startup'),
            'Excerpt Content' => __('Excerpt Content','smallbiz-startup'),
            'Full Content' => __('Full Content','smallbiz-startup'),
        ),
	) );

	// Footer Section 
	$wp_customize->add_section('smallbiz_startup_footer', array(
		'title'	=> __('Manage Footer Section','smallbiz-startup'),
		'description'	=> __('<p class="sec-title">Manage Footer Section</p>','smallbiz-startup'),
		'priority'	=> null,
		'panel' => 'smallbiz_startup_panel_area',
	));

	$wp_customize->add_setting('smallbiz_startup_footer_widget', array(
	    'default' => false,
	    'sanitize_callback' => 'smallbiz_startup_sanitize_checkbox',
	));
	$wp_customize->add_control('smallbiz_startup_footer_widget', array(
	    'settings' => 'smallbiz_startup_footer_widget', // Corrected setting name
	    'section'   => 'smallbiz_startup_footer',
	    'label'     => __('Check to Enable Footer Widget', 'smallbiz-startup'),
	    'type'      => 'checkbox',
	));

	$wp_customize->add_setting('smallbiz_startup_copyright_line',array(
		'sanitize_callback' => 'sanitize_text_field',
	));	
	$wp_customize->add_control( 'smallbiz_startup_copyright_line', array(
	   'section' 	=> 'smallbiz_startup_footer',
	   'label'	 	=> __('Copyright Line','smallbiz-startup'),
	   'type'    	=> 'text',
	   'priority' 	=> null,
    ));

    $wp_customize->add_setting('smallbiz_startup_scroll_hide', array(
        'default' => false,
        'sanitize_callback' => 'smallbiz_startup_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'smallbiz_startup_scroll_hide',array(
        'label'          => __( 'Check To Show Scroll To Top', 'smallbiz-startup' ),
        'section'        => 'smallbiz_startup_footer',
        'settings'       => 'smallbiz_startup_scroll_hide',
        'type'           => 'checkbox',
    )));

	$wp_customize->add_setting('smallbiz_startup_color_scheme_gradiant1',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));

   	$wp_customize->add_control( 
	    new WP_Customize_Color_Control( 
	    $wp_customize, 
	    'smallbiz_startup_color_scheme_gradiant1', 
	    array(
	        'label'      => __( 'Gradiant Color Scheme', 'smallbiz-startup' ),
	        'section'    => 'colors',
	        'settings'   => 'smallbiz_startup_color_scheme_gradiant1',
	    ) ) 
	);

	$wp_customize->add_setting('smallbiz_startup_color_scheme_gradiant2',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));

    $wp_customize->add_control( 
	    new WP_Customize_Color_Control( 
	    $wp_customize, 
	    'smallbiz_startup_color_scheme_gradiant2', 
	    array(
	        'label'      => __( 'Gradiant Color Scheme', 'smallbiz-startup' ),
	        'section'    => 'colors',
	        'settings'   => 'smallbiz_startup_color_scheme_gradiant2',
	    ) ) 
	);

	$wp_customize->add_setting('smallbiz_startup_woocommerce_sidebar_shop',array(
		'sanitize_callback' => 'smallbiz_startup_sanitize_checkbox',
	));
	$wp_customize->add_control( 'smallbiz_startup_woocommerce_sidebar_shop', array(
	   'section'   => 'woocommerce_product_catalog',
	   'description'  => __('Click on the check box to remove sidebar from shop page.','smallbiz-startup'),
	   'label'	=> __('Shop Page Sidebar layout','smallbiz-startup'),
	   'type'      => 'checkbox'
 	));

	$wp_customize->add_setting('smallbiz_startup_woocommerce_sidebar_product',array(
		'sanitize_callback' => 'smallbiz_startup_sanitize_checkbox',
	));
	$wp_customize->add_control( 'smallbiz_startup_woocommerce_sidebar_product', array(
	   'section'   => 'woocommerce_product_catalog',
	   'description'  => __('Click on the check box to remove sidebar from product page.','smallbiz-startup'),
	   'label'	=> __('Product Page Sidebar layout','smallbiz-startup'),
	   'type'      => 'checkbox'
 	));

 	// Google Fonts
    $wp_customize->add_section( 'smallbiz_startup_google_fonts_section', array(
		'title'       => __( 'Google Fonts', 'smallbiz-startup' ),
		'priority'       => 24,
	) );

	$font_choices = array(
		'Kaushan Script:' => 'Kaushan Script',
		'Emilys Candy:' => 'Emilys Candy',
		'Poppins:0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900' => 'Poppins',
		'Source Sans Pro:400,700,400italic,700italic' => 'Source Sans Pro',
		'Open Sans:400italic,700italic,400,700' => 'Open Sans',
		'Oswald:400,700' => 'Oswald',
		'Playfair Display:400,700,400italic' => 'Playfair Display',
		'Montserrat:400,700' => 'Montserrat',
		'Raleway:400,700' => 'Raleway',
		'Droid Sans:400,700' => 'Droid Sans',
		'Lato:400,700,400italic,700italic' => 'Lato',
		'Arvo:400,700,400italic,700italic' => 'Arvo',
		'Lora:400,700,400italic,700italic' => 'Lora',
		'Merriweather:400,300italic,300,400italic,700,700italic' => 'Merriweather',
		'Oxygen:400,300,700' => 'Oxygen',
		'PT Serif:400,700' => 'PT Serif',
		'PT Sans:400,700,400italic,700italic' => 'PT Sans',
		'PT Sans Narrow:400,700' => 'PT Sans Narrow',
		'Cabin:400,700,400italic' => 'Cabin',
		'Fjalla One:400' => 'Fjalla One',
		'Francois One:400' => 'Francois One',
		'Josefin Sans:400,300,600,700' => 'Josefin Sans',
		'Libre Baskerville:400,400italic,700' => 'Libre Baskerville',
		'Arimo:400,700,400italic,700italic' => 'Arimo',
		'Ubuntu:400,700,400italic,700italic' => 'Ubuntu',
		'Bitter:400,700,400italic' => 'Bitter',
		'Droid Serif:400,700,400italic,700italic' => 'Droid Serif',
		'Roboto:400,400italic,700,700italic' => 'Roboto',
		'Open Sans Condensed:700,300italic,300' => 'Open Sans Condensed',
		'Roboto Condensed:400italic,700italic,400,700' => 'Roboto Condensed',
		'Roboto Slab:400,700' => 'Roboto Slab',
		'Yanone Kaffeesatz:400,700' => 'Yanone Kaffeesatz',
		'Rokkitt:400' => 'Rokkitt',
	);

	$wp_customize->add_setting( 'smallbiz_startup_headings_fonts', array(
		'sanitize_callback' => 'smallbiz_startup_sanitize_fonts',
	));
	$wp_customize->add_control( 'smallbiz_startup_headings_fonts', array(
		'type' => 'select',
		'description' => __('Select your desired font for the headings.', 'smallbiz-startup'),
		'section' => 'smallbiz_startup_google_fonts_section',
		'choices' => $font_choices
	));

	$wp_customize->add_setting( 'smallbiz_startup_body_fonts', array(
		'sanitize_callback' => 'smallbiz_startup_sanitize_fonts'
	));
	$wp_customize->add_control( 'smallbiz_startup_body_fonts', array(
		'type' => 'select',
		'description' => __( 'Select your desired font for the body.', 'smallbiz-startup' ),
		'section' => 'smallbiz_startup_google_fonts_section',
		'choices' => $font_choices
	));
}
add_action( 'customize_register', 'smallbiz_startup_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function smallbiz_startup_customize_preview_js() {
	wp_enqueue_script( 'smallbiz_startup_customizer', esc_url(get_template_directory_uri()) . '/js/customize-preview.js', array( 'customize-preview' ), '20161510', true );
}
add_action( 'customize_preview_init', 'smallbiz_startup_customize_preview_js' );